@@ -4,7 +4,7 @@
 """
    TODO Purpose of the file
    @project: HSPyLib
-   hspylib.app.vault.src.main
+   @package: hspylib.app.vault.src.main
       @file: __main__.py
    @created: Tue, 4 May 2021
     @author: <B>H</B>ugo <B>S</B>aporetti <B>J</B>unior"
@@ -23,7 +23,6 @@ from textwrap import dedent
 from hspylib.core.tools.commons import get_path, syserr
 from hspylib.modules.cli.application.application import Application
 from hspylib.modules.cli.application.version import AppVersion
-
 from vault.core.vault import Vault
 from vault.core.vault_config import VaultConfig
 
