@@ -4,7 +4,7 @@
 """
    TODO Purpose of the file
    @project: HSPyLib
-   hspylib.app.vault.core
+   @package: hspylib.app.vault.core
       @file: vault.py
    @created: Tue, 4 May 2021
     @author: <B>H</B>ugo <B>S</B>aporetti <B>J</B>unior"
@@ -27,7 +27,6 @@ from cryptography.fernet import InvalidToken
 from hspylib.core.tools.commons import file_is_not_empty, safe_del_file, syserr, sysout, touch_file
 from hspylib.modules.cli.tui.menu.menu_utils import MenuUtils
 from hspylib.modules.security.security import decrypt, encrypt
-
 from vault.core.vault_config import VaultConfig
 from vault.core.vault_service import VaultService
 from vault.entity.vault_entry import VaultEntry
@@ -144,8 +143,8 @@ class Vault:
         :param key: The vault entry name to get
         """
         entry = self.service.get_by_key(key)
-        entry.password = cryptocode.decrypt(entry.password, self._VAULT_HASHCODE)
         if entry:
+            entry.password = cryptocode.decrypt(entry.password, self._VAULT_HASHCODE)
             sysout(f"\n{entry.to_string(True, True)}")
         else:
             log.error("Attempt to get from Vault failed for name=%s", key)
